@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-03-10'; # DATE
+our $DATE = '2023-03-31'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.022'; # VERSION
+our $VERSION = '1.023'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -50,10 +50,13 @@ will result in:
     ,,,X
     ,,,Y
 
+Keywords: join, merge
+
 _
     add_args => {
         %App::CSVUtils::argspecopt_with_data_rows,
     },
+    tags => ['category:combining', 'join', 'merge'],
 
     reads_multiple_csv => 1,
 
@@ -129,7 +132,7 @@ App::CSVUtils::csv_concat - Concatenate several CSV files together, collecting a
 
 =head1 VERSION
 
-This document describes version 1.022 of App::CSVUtils::csv_concat (from Perl distribution App-CSVUtils), released on 2023-03-10.
+This document describes version 1.023 of App::CSVUtils::csv_concat (from Perl distribution App-CSVUtils), released on 2023-03-31.
 
 =head1 FUNCTIONS
 
@@ -172,6 +175,8 @@ will result in:
  ,,,X
  ,,,Y
 
+Keywords: join, merge
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
